#  -*- coding: utf-8 -*-
#
#  GSXML - A Content Import/Export Product
#
#  Export Browser view
#
#  Copyright (c) 2006-2007 InQuant GmbH
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
""" Provide a GUI for the GSXML Export step
"""

__author__ = """Ramon Bartl <ramonski@ramonski.de>"""
__docformat__ = 'restructuredtext'
__revision__ = "$Revision: 41539 $"


import os
import logging
from zope.formlib import form
from Products.Five.formlib import formbase
from Products.Five.browser import pagetemplatefile

# import gsxml stuff
from inquant.plone.gsxml.interfaces import IGmailConfig, IFSConfig, ITarConfig
from inquant.plone.gsxml.context import GmailExportContext, SimpleFSExportContext, TarballExportContext
from inquant.plone.gsxml.content import XMLContentRootExporter

from inquant.plone.gsxml import utils

TEMPLATE_PATH=os.path.abspath( os.path.join( os.path.dirname(__file__), "..", "templates" ) )
FORM_TEMPLATE=os.path.join( TEMPLATE_PATH, "gsxml_form.pt" )

LOGGER="gsxml.exportview"

def info(msg):
    logging.getLogger(LOGGER).info(msg)

def debug(msg):
    logging.getLogger(LOGGER).debug(msg)

def error(msg):
    logging.getLogger(LOGGER).error(msg)


class GmailForm(formbase.PageForm):
    form_fields = form.FormFields(IGmailConfig)
    template = pagetemplatefile.ZopeTwoPageTemplateFile( FORM_TEMPLATE )
    label = "GSXML Gmail Export"

    @form.action("export as single files per mail")
    def action_export(self, action, data):
        """ send one file per mail """
        ex = XMLContentRootExporter( self.context )
        ec = GmailExportContext(data["username"], data["password"], exportid=data["exportid"])
        ex.export(ec, "structure", False)

    @form.action("export as compressed archive")
    def action_export(self, action, data):
        """ send a tar.gz in one mail """
        ex = XMLContentRootExporter( self.context )
        ec = TarballExportContext()
        ex.export(ec, "structure", False)
        gmail = GmailExportContext(data["username"], data["password"], exportid=data["exportid"])
        file = ec.getArchiveStream()
        file.seek(0)
        name = ec.getArchiveFilename()
        gmail.writeDataFile(name, file.read(), "application/x-tar")


class FSForm(formbase.PageForm):
    form_fields = form.FormFields(IFSConfig)
    template = pagetemplatefile.ZopeTwoPageTemplateFile( FORM_TEMPLATE )
    label = "GSXML Filesystem Export"

    @form.action("export")
    def action_export(self, action, data):
        """ save the file to the given location """
        if data["path"] is not None:
            ex = XMLContentRootExporter( self.context )
            ec = SimpleFSExportContext( data["path"] )
            ex.export(ec, "structure", False)
        else:
            self.status = "You have to fill in a Path and a foldername"


class TarForm(formbase.PageForm):
    form_fields = form.FormFields(ITarConfig)
    template = pagetemplatefile.ZopeTwoPageTemplateFile( FORM_TEMPLATE )
    label = "GSXML Tar Export"

    @form.action("download")
    def action_download(self, action, data):
        """ download the export tar """
        ex = XMLContentRootExporter( self.context )
        ec = TarballExportContext()
        ex.export(ec, "structure", False)

        file = ec.getArchiveStream()
        name = ec.getArchiveFilename()
        size = ec.getArchiveSize()

        return utils.download_file( self.request.RESPONSE, file, name, size, mime_type="application/x-tar" )


# vim: set ft=python ts=4 sw=4 expandtab :
