#  -*- coding: utf-8 -*-
#
#  GSXML - A Content Import/Export Product
#
#  Export Browser view
#
#  Copyright (c) 2006-2007 InQuant GmbH
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
""" Provide a GUI for the GSXML Tool
"""

__author__ = """Ramon Bartl <ramonski@ramonski.de>"""
__docformat__ = 'restructuredtext'
__revision__ = "$Revision: 41539 $"


import os
import logging
from StringIO import StringIO
from zope.formlib import form
from Products.Five.formlib import formbase
from Products.Five.browser import pagetemplatefile

# import gsxml stuff
from inquant.plone.gsxml.interfaces import ITarConfig
from inquant.plone.gsxml.context import TarballImportContext, TarballExportContext
from inquant.plone.gsxml.content import XMLContentRootImporter, XMLContentRootExporter

from inquant.plone.gsxml import utils

TEMPLATE_PATH=os.path.abspath( os.path.join( os.path.dirname(__file__), "..", "templates" ) )
FORM_TEMPLATE=os.path.join( TEMPLATE_PATH, "gsxml_form.pt" )

LOGGER="gsxml.browserview"

class GSXMLForm(formbase.PageForm):
    form_fields = form.FormFields(ITarConfig)
    template = pagetemplatefile.ZopeTwoPageTemplateFile( FORM_TEMPLATE )
    label = "GSXML"

    @form.action("download")
    def action_download(self, action, data):
        """ download the export tar """
        ex = XMLContentRootExporter( self.context )
        ec = TarballExportContext()
        ex.export(ec, "structure", False)

        file = ec.getArchiveStream()
        name = ec.getArchiveFilename()
        size = ec.getArchiveSize()

        return utils.download_file( self.request.RESPONSE, file, name, size, mime_type="application/x-tar" )


    @form.action("upload tar-file")
    def action_import(self, action, data):
        """ import from a given location """
        im = XMLContentRootImporter( self.context )
        ic = TarballImportContext( StringIO(data["path"]) )
        im.import_(ic, "structure", False)





# vim: set ft=python ts=4 sw=4 expandtab :
