#  -*- coding: utf-8 -*-
#
#  GSXML - A Content Import/Export Product
#
#  Provide functionality of GenericSetup and the Marshaller
#
#  Copyright (c) 2006-2007 InQuant GmbH
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
""" A set of Interfaces that provide functionality for Import and Export.
"""

__author__ = """Ramon Bartl <ramonski@ramonski.de>"""
__docformat__ = 'restructuredtext'
__revision__ = "$Revision: 41534 $"

from zope.interface import Interface, Attribute
from zope import schema

#from Interface.bridge import createZope3Bridge

from Products.GenericSetup.interfaces import IFilesystemExporter
from Products.GenericSetup.interfaces import IFilesystemImporter


from constraint import validate_email


class IGSXMLFilesystemImporter(IFilesystemImporter):
    """
    a proxy interface that inherits from IFilesystemImporter.
    This is important that our adapters are called.
    """

class IGSXMLFilesystemExporter(IFilesystemExporter):
    """
    a proxy interface that inherits from IFilesystemExporter.
    This is important that our adapters are called.
    """

class IXMLExportableContent(Interface):
    """
    A marker interface for all content which is exportable as
    XML in some ways. Objects marked in that way must implement IFilesystemExporter
    and IFilesystemImporter (or have adapters).
    """

# XXX: Why does'nt this work:
# In [1]: pi = portal.portal_interface
# In [8]: pi.objectImplements( portal.test, "Products.gsxml.IXMLExportableContent" )
# Out[8]: 0
#
# But this does:
# In [4]: from Products.gsxml.interfaces import *
# In [5]: IXMLExportableContent.providedBy( portal.test )
# Out[5]: True
#
#from Products import gsxml
#createZope3Bridge(IXMLExportableContent, gsxml, 'IXMLExportableContent')

class IXMLMarshaller(Interface):
    """
    An Interface that delivers xml
    """
    xml = Attribute(u"the XML representation of the content")

class IXMLDemarshaller(Interface):
    """
    An interface for objects which can demarshall xml to an
    existing object instance.
    """
    def demarshall( instance, xml ):
        """
        Demarshall the xml to the supplied object instance.
        """

class IFSEnv(Interface):
    """
    An interface for objects which want to store data in a fs like environment
    """
    def write( path, content ):
        """
        create a "file" with the content
        """

    def read( path ):
        """
        read the content of a file
        """

    def listdir( path ):
        """
        list the content of the directory
        """

    def isdir( path ):
        """
        checks for file/directory
        """

    def exists( path ):
        """
        checks if the path exists
        """

    def lookup( path ):
        """
        """

class IGmailConfig(Interface):
    """
    A Gmail Import/Export Form
    """

    username = schema.TextLine(title=u'Gmail Email Address',
                           description=u'e.g. user@googlemail.com',
                           constraint=validate_email,
                           required=True)

    password = schema.Password(title=u'Gmail Password',
                           description=u'e.g. *****',
                           required=True)

    exportid = schema.TextLine(title=u'Gmail Export ID',
                           description=u'e.g. my-export-unified-identifier-1234',
                           required=True)


class IFSConfig(Interface):
    """
    A FS Import/Export Form
    """

    path = schema.TextLine(title=u'Path',
                           description=u'e.g. /home/user/Desktop/export',
                           required=True)


class ITarConfig(Interface):
    """
    A Tar Import/Export Form
    """
    path = schema.Bytes(title=u'Path',
                           description=u'Select a Tar File',
                           required=False)


# vim: set ts=4 sw=4 expandtab:
